.. BalderHub SNMPAgent documentation master file, created by
   sphinx-quickstart on Wed Feb 22 19:24:39 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

BalderHub-GUI
=============

The BalderHub GUI package provides basic tests for testing graphical user interfaces of different kinds. It is an
universal package, that provides general concepts of GUIs.

.. note::
   Please note, this package is still under development. If you would
   like to contribute, take a look into the `GitHub project <https://github.com/balder-dev/balderhub-gui>`_.

This is a BalderHub package for the `Balder <https://docs.balder.dev/>`_ test framework. It allows you to test GUI of
different kinds, without the need of writing own tests. If you are new to Balder check out the
`official documentation <https://docs.balder.dev>`_ first.


.. toctree::
   :maxdepth: 2

   installation.rst
   topic_intro.rst
   scenarios.rst
   features.rst
   examples.rst
   utilities.rst
